#!/usr/bin/python3
"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          25-06-2018
//      Created for Project :   FLAME
"""

import os
import sys
from sqlalchemy import engine_from_config
from pyramid.paster import get_appsettings, setup_logging
from clmcservice.models.meta import Base


def usage(argv):
    """
    A method to be called when the script has been used in an incorrect way.

    :param argv: cmd arguments
    """

    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri>\n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    """
    Main method of the script - initialises the database by creating all tables declared in the models.py module

    :param argv: command line arguments - expects a configuration .ini file from which it retrieves the URL with which to connect to postgresql
    """

    if len(argv) != 2:
        usage(argv)  # in case of wrong usage

    config_uri = argv[1]
    setup_logging(config_uri)

    settings = get_appsettings(config_uri)  # get application specific settings
    engine = engine_from_config(settings, 'sqlalchemy.')  # create the db engine from the sqlalchemy setting configured in the .ini file

    Base.metadata.create_all(engine)  # creates all model tables
